@@ -11,9 +11,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
 import unittest
 
+import mock
+
 from tuskar.heat import template_tools
 
 
@@ -39,14 +40,16 @@ class TemplateToolsTests(unittest.TestCase):
         template_tools.merge_templates(overcloud_roles)
 
         # Verify
-        mock_merge.assert_called_once_with([
-            '/etc/tuskar/tripleo-heat-templates/overcloud-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
-            '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml', ],
+        mock_merge.assert_called_once_with(
+            [
+                '/etc/tuskar/tripleo-heat-templates/overcloud-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
+                '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml'
+            ],
             None,
             None,
             scaling={
@@ -64,14 +67,16 @@ class TemplateToolsTests(unittest.TestCase):
         template_tools.merge_templates(overcloud_roles)
 
         # Verify
-        mock_merge.assert_called_once_with([
-            '/etc/tuskar/tripleo-heat-templates/overcloud-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
-            '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml', ],
+        mock_merge.assert_called_once_with(
+            [
+                '/etc/tuskar/tripleo-heat-templates/overcloud-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
+                '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml'
+            ],
             None,
             None,
             scaling={
@@ -89,14 +94,16 @@ class TemplateToolsTests(unittest.TestCase):
         template_tools.merge_templates(overcloud_roles)
 
         # Verify
-        mock_merge.assert_called_once_with([
-            '/etc/tuskar/tripleo-heat-templates/overcloud-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
-            '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml', ],
+        mock_merge.assert_called_once_with(
+            [
+                '/etc/tuskar/tripleo-heat-templates/overcloud-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
+                '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
+                '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml'
+            ],
             None,
             None,
             scaling={
