@@ -39,5 +39,5 @@ class PolicyFixture(fixtures.Fixture):
         self.addCleanup(tuskar_policy.reset)
 
     def set_rules(self, rules):
-        common_policy.set_rules(common_policy.Rules(
-            dict((k, common_policy.parse_rule(v)) for k, v in rules.items())))
+        common_policy.set_rules(dict((k, common_policy.parse_rule(v))
+                                     for k, v in rules.items()))
